Players
=======

Information
-----------
Name:
  ``pyplanet.apps.contrib.players``
Depends on:
  ``core.maniaplanet``
Game:
  Trackmania, Trackmania Next, Shootmania

Features
--------
This app provides the playerlist UI.

Commands
--------

Display playerlist
~~~~~~~~~~~~~~~~~~
Command:
  ``/players``
Parameters:
  None.
Functionality:
  Displays a list of players currently on the server.
Required permission:
  None.

Show last online date of player
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
Command:
  ``/laston`` / ``/lastseen``
Parameters:
  * Login of the player.
Functionality:
  Display the last date and time the user has been seen on the server.
Required permission:
  None.

Signal handlers
---------------
None.
